@@ -13,3 +13,7 @@ import argparse
 def _subparser(parser: argparse.ArgumentParser) -> None:
     """Manage Notifications (Android, iOS, Web)"""
     _subparsers = parser.add_subparsers(dest="action", required=True)
+
+
+class JaxlNotificationsSDK:
+    pass
